@@ -19,14 +19,17 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.texttospeech_v1.types import cloud_tts
 from .transports.base import TextToSpeechTransport, DEFAULT_CLIENT_INFO
@@ -176,12 +179,13 @@ class TextToSpeechAsyncClient:
                 `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
                 language tag. If specified, the ListVoices call will
                 only return voices that can be used to synthesize this
-                language_code. E.g. when specifying "en-NZ", you will
-                get supported "en-\*" voices; when specifying "no", you
-                will get supported "no-\*" (Norwegian) and "nb-\*"
-                (Norwegian Bokmal) voices; specifying "zh" will also get
-                supported "cmn-\*" voices; specifying "zh-hk" will also
-                get supported "yue-\*" voices.
+                language_code. E.g. when specifying ``"en-NZ"``, you
+                will get supported ``"en-\*"`` voices; when specifying
+                ``"no"``, you will get supported ``"no-\*"`` (Norwegian)
+                and ``"nb-\*"`` (Norwegian Bokmal) voices; specifying
+                ``"zh"`` will also get supported ``"cmn-\*"`` voices;
+                specifying ``"zh-hk"`` will also get supported
+                ``"yue-\*"`` voices.
 
                 This corresponds to the ``language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
