@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.texttospeech_v1.types import cloud_tts
 from .transports.base import TextToSpeechTransport, DEFAULT_CLIENT_INFO
@@ -264,8 +266,15 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
             client_options = client_options_lib.ClientOptions()
 
         # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
+            "true",
+            "false",
+        ):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        use_client_cert = (
+            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
         )
 
         client_cert_source_func = None
@@ -350,12 +359,13 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
                 `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
                 language tag. If specified, the ListVoices call will
                 only return voices that can be used to synthesize this
-                language_code. E.g. when specifying "en-NZ", you will
-                get supported "en-\*" voices; when specifying "no", you
-                will get supported "no-\*" (Norwegian) and "nb-\*"
-                (Norwegian Bokmal) voices; specifying "zh" will also get
-                supported "cmn-\*" voices; specifying "zh-hk" will also
-                get supported "yue-\*" voices.
+                language_code. E.g. when specifying ``"en-NZ"``, you
+                will get supported ``"en-\*"`` voices; when specifying
+                ``"no"``, you will get supported ``"no-\*"`` (Norwegian)
+                and ``"nb-\*"`` (Norwegian Bokmal) voices; specifying
+                ``"zh"`` will also get supported ``"cmn-\*"`` voices;
+                specifying ``"zh-hk"`` will also get supported
+                ``"yue-\*"`` voices.
 
                 This corresponds to the ``language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
