@@ -63,12 +63,12 @@ class ListVoicesRequest(proto.Message):
             `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
             language tag. If specified, the ListVoices call will only
             return voices that can be used to synthesize this
-            language_code. E.g. when specifying "en-NZ", you will get
-            supported "en-\*" voices; when specifying "no", you will get
-            supported "no-\*" (Norwegian) and "nb-\*" (Norwegian Bokmal)
-            voices; specifying "zh" will also get supported "cmn-\*"
-            voices; specifying "zh-hk" will also get supported "yue-\*"
-            voices.
+            language_code. E.g. when specifying ``"en-NZ"``, you will
+            get supported ``"en-\*"`` voices; when specifying ``"no"``,
+            you will get supported ``"no-\*"`` (Norwegian) and
+            ``"nb-\*"`` (Norwegian Bokmal) voices; specifying ``"zh"``
+            will also get supported ``"cmn-\*"`` voices; specifying
+            ``"zh-hk"`` will also get supported ``"yue-\*"`` voices.
     """
 
     language_code = proto.Field(proto.STRING, number=1,)
@@ -146,6 +146,7 @@ class SynthesisInput(proto.Message):
     Attributes:
         text (str):
             The raw text to be synthesized.
+
             This field is a member of `oneof`_ ``input_source``.
         ssml (str):
             The SSML document to be synthesized. The SSML document must
@@ -153,6 +154,7 @@ class SynthesisInput(proto.Message):
             return [google.rpc.Code.INVALID_ARGUMENT][]. For more
             information, see
             `SSML <https://cloud.google.com/text-to-speech/docs/ssml>`__.
+
             This field is a member of `oneof`_ ``input_source``.
     """
 
