@@ -28,6 +28,7 @@ __protobuf__ = proto.module(
         "SynthesisInput",
         "VoiceSelectionParams",
         "AudioConfig",
+        "CustomVoiceParams",
         "SynthesizeSpeechResponse",
         "Timepoint",
     },
@@ -68,12 +69,12 @@ class ListVoicesRequest(proto.Message):
             language tag. If not specified, the API will return all
             supported voices. If specified, the ListVoices call will
             only return voices that can be used to synthesize this
-            language_code. E.g. when specifying "en-NZ", you will get
-            supported "en-NZ" voices; when specifying "no", you will get
-            supported "no-\*" (Norwegian) and "nb-\*" (Norwegian Bokmal)
-            voices; specifying "zh" will also get supported "cmn-\*"
-            voices; specifying "zh-hk" will also get supported "yue-hk"
-            voices.
+            language_code. E.g. when specifying ``"en-NZ"``, you will
+            get supported ``"en-NZ"`` voices; when specifying ``"no"``,
+            you will get supported ``"no-\*"`` (Norwegian) and
+            ``"nb-\*"`` (Norwegian Bokmal) voices; specifying ``"zh"``
+            will also get supported ``"cmn-\*"`` voices; specifying
+            ``"zh-hk"`` will also get supported ``"yue-hk"`` voices.
     """
 
     language_code = proto.Field(proto.STRING, number=1,)
@@ -164,6 +165,7 @@ class SynthesisInput(proto.Message):
     Attributes:
         text (str):
             The raw text to be synthesized.
+
             This field is a member of `oneof`_ ``input_source``.
         ssml (str):
             The SSML document to be synthesized. The SSML document must
@@ -171,6 +173,7 @@ class SynthesisInput(proto.Message):
             return [google.rpc.Code.INVALID_ARGUMENT][]. For more
             information, see
             `SSML <https://cloud.google.com/text-to-speech/docs/ssml>`__.
+
             This field is a member of `oneof`_ ``input_source``.
     """
 
@@ -208,11 +211,16 @@ class VoiceSelectionParams(proto.Message):
             not requirement; if a voice of the appropriate gender is not
             available, the synthesizer should substitute a voice with a
             different gender rather than failing the request.
+        custom_voice (google.cloud.texttospeech_v1beta1.types.CustomVoiceParams):
+            The configuration for a custom voice. If
+            [CustomVoiceParams.model] is set, the service will choose
+            the custom voice matching the specified configuration.
     """
 
     language_code = proto.Field(proto.STRING, number=1,)
     name = proto.Field(proto.STRING, number=2,)
     ssml_gender = proto.Field(proto.ENUM, number=3, enum="SsmlVoiceGender",)
+    custom_voice = proto.Field(proto.MESSAGE, number=4, message="CustomVoiceParams",)
 
 
 class AudioConfig(proto.Message):
@@ -270,6 +278,31 @@ class AudioConfig(proto.Message):
     effects_profile_id = proto.RepeatedField(proto.STRING, number=6,)
 
 
+class CustomVoiceParams(proto.Message):
+    r"""Description of the custom voice to be synthesized.
+
+    Attributes:
+        model (str):
+            Required. The name of the AutoML model that
+            synthesizes the custom voice.
+        reported_usage (google.cloud.texttospeech_v1beta1.types.CustomVoiceParams.ReportedUsage):
+            Optional. The usage of the synthesized audio
+            to be reported.
+    """
+
+    class ReportedUsage(proto.Enum):
+        r"""The usage of the synthesized audio. You must report your
+        honest and correct usage of the service as it's regulated by
+        contract and will cause significant difference in billing.
+        """
+        REPORTED_USAGE_UNSPECIFIED = 0
+        REALTIME = 1
+        OFFLINE = 2
+
+    model = proto.Field(proto.STRING, number=1,)
+    reported_usage = proto.Field(proto.ENUM, number=3, enum=ReportedUsage,)
+
+
 class SynthesizeSpeechResponse(proto.Message):
     r"""The message returned to the client by the ``SynthesizeSpeech``
     method.
